(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.popular_tags = {
    attach(context, settings) {
      once(
        'popular_tags_item',
        '.popular-tags .tag-terms .term',
        context,
      ).forEach((elem) => {
        elem.addEventListener('click', function (evt) {
          const parent = this.closest('.field--type-entity-reference');
          evt.preventDefault();
          if (parent.querySelector('.autocomplete-deluxe-container')) {
            const inputContainer = parent.querySelector(
              '.autocomplete-deluxe-container',
            );
            const input = this.closest(
              '.autocomplete-deluxe-value-container',
            ).querySelector('input[type="text"]');
            const currentVal = input.value;
            const newTerm = this.textContent;
            // Create an array of "terms" from the input's value.
            const terms = currentVal.split('"').filter((term) => term.trim());
            // If term already exists in the list, do nothing.
            if (terms.includes(newTerm)) {
              return false;
            }
            // If field not empty.
            if (currentVal.replaceAll('"', '')) {
              input.value = `${currentVal} ""${newTerm}""`;
            } else {
              input.value = `""${newTerm}""`;
            }
            const newItemElem = document.createElement('span');
            newItemElem.classList.add('autocomplete-deluxe-item');
            newItemElem.appendChild(document.createTextNode(newTerm));
            const deluxeLink = document.createElement('a');
            deluxeLink.classList.add('autocomplete-deluxe-item-delete');
            newItemElem.appendChild(deluxeLink);

            newItemElem.querySelectorAll('a').forEach((aTag) => {
              aTag.addEventListener('mousedown', () => {
                let newValue = input.value.replace(`""${newTerm}""`, '');
                newValue = newValue.trim();
                newItemElem.parentElement.nextSibling.querySelector(
                  '.autocomplete-deluxe-value-field',
                ).value = newValue;
                newItemElem.remove();
              });
            });

            if (inputContainer.querySelector('.autocomplete-deluxe-item')) {
              inputContainer
                .querySelector('.autocomplete-deluxe-item:last-of-type')
                .insertAdjacentElement('afterend', newItemElem);
            } else {
              inputContainer.prepend(newItemElem);
            }
            return false;
          }
          const inp = parent.querySelector(
            'input[type="text"].form-autocomplete',
          );
          const val = inp.value;
          const term = this.textContent;
          const tid = this.dataset.tid;
          if (val.indexOf(term) === 0) {
            return false;
          }
          if (val.indexOf(`, ${term}`) >= 0) {
            return false;
          }
          inp.value = val ? `${val}, ${term} (${tid})` : `${term} (${tid})`;
          return false;
        });
      });
      if (drupalSettings.popular_tags) {
        Object.keys(drupalSettings.popular_tags).forEach((fieldName) => {
          const _fieldName = fieldName.replace('_', '-');
          const fieldContainer = context.querySelector(
            `#edit-${_fieldName}-wrapper`,
          );
          const tagContainer = fieldContainer.querySelector('.popular-tags');
          const showAllLink = tagContainer.querySelector('a.show-all-terms');
          const hideLink = tagContainer.querySelector('a.show-popular-terms');
          showAllLink.addEventListener('click', function () {
            this.style.display = 'none';
            hideLink.style.display = 'inline';
            tagContainer
              .querySelectorAll('.term:not(.popular)')
              .forEach((term) => {
                term.style.display = 'inline-flex';
              });
            return false;
          });
          hideLink.addEventListener('click', function () {
            this.style.display = 'none';
            showAllLink.style.display = 'inline';
            tagContainer
              .querySelectorAll('.term:not(.popular)')
              .forEach((term) => {
                term.style.display = 'none';
              });
            return false;
          });
          hideLink.click();
        });
      }
    },
  };
})(jQuery, Drupal, drupalSettings);
